"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var getTypescriptField_1 = require("./getTypescriptField");
function default_1(includeTypeName, typeNamePrefix, typeNamePostfix) {
    return function (type) {
        if (type.name.startsWith('__')) {
            return;
        }
        switch (type.kind) {
            case 'OBJECT':
            case 'INTERFACE':
                return objectType(type, includeTypeName, typeNamePrefix, typeNamePostfix);
            case 'INPUT_OBJECT':
                return inputObjectType(type, typeNamePrefix, typeNamePostfix);
            case 'ENUM':
                return enumType(type);
            case 'SCALAR':
                return scalarType(type);
            case 'UNION':
                return unionType(type);
            default:
                console.log('MISSED GENERATION FOR', type);
                return;
        }
    };
}
exports.default = default_1;
function objectType(type, includeTypeName, typeNamePrefix, typeNamePostfix) {
    var fields = type.fields
        .map(function (x) { return (0, getTypescriptField_1.default)(x.name, x.type); })
        .map(function (x) { return "\t" + x; })
        .join('\n');
    var typeName = type.name;
    return "\nexport interface " + typeNamePrefix + typeName + typeNamePostfix + " {" + (includeTypeName
        ? "\n\t__typename:\"" + typeName + "\""
        : '') + "\n" + fields + "\n}\n" + (typeNamePrefix || typeNamePostfix
        ? "type " + typeName + " = " + typeNamePrefix + typeName + typeNamePostfix
        : '');
}
function inputObjectType(type, typeNamePrefix, typeNamePostfix) {
    var fields = type.inputFields
        .map(function (x) { return (0, getTypescriptField_1.default)(x.name, x.type); })
        .map(function (x) { return "\t" + x; })
        .join('\n');
    var typeName = type.name;
    return "\nexport interface " + typeNamePrefix + typeName + typeNamePostfix + " {\n" + fields + "\n}";
}
function enumType(type) {
    var typeName = type.name;
    var fields = type.enumValues
        .map(function (x) { return "\t" + x.name + " = '" + x.name + "',"; })
        .join('\n');
    return "\nexport enum " + typeName + " {\n" + fields + "\n}";
}
function scalarType(type) {
    var typeName = type.name;
    var tsType = '';
    switch (typeName) {
        case 'ID':
            tsType = 'string';
            break;
        case 'String':
            tsType = 'string';
            break;
        case 'Int':
            tsType = 'number';
            break;
        case 'Float':
            tsType = 'number';
            break;
        case 'Boolean':
            tsType = 'boolean';
            break;
        case 'DateTime':
        case 'Time':
            tsType = 'Date';
            break;
        // Date already exists in JS
        case 'Date':
            return '';
        case 'JSON':
            tsType = 'any';
            break;
        default:
            tsType = 'any';
            break;
    }
    // export ID for later use in the application
    if (typeName === 'ID') {
        return "export type " + typeName + " = " + tsType;
    }
    return "type " + typeName + " = " + tsType;
}
function unionType(type) {
    var typeName = type.name;
    var valueTypes = type.possibleTypes.map(function (x) { return x.name; }).join(' | ');
    return "export type " + typeName + " = " + valueTypes;
}
