"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function getTypescriptField(fieldName, type, _a) {
    var _b = _a === void 0 ? {
        isNullable: true,
        isList: false,
        isListItemNullable: true,
    } : _a, _c = _b.isNullable, isNullable = _c === void 0 ? true : _c, _d = _b.isList, isList = _d === void 0 ? false : _d, _e = _b.isListItemNullable, isListItemNullable = _e === void 0 ? true : _e;
    switch (type.kind) {
        case 'INPUT_OBJECT':
        case 'ENUM':
        case 'OBJECT':
        case 'INTERFACE':
        case 'SCALAR':
        case 'UNION':
            return buildField(fieldName, type.name, isNullable, isList, isListItemNullable);
        case 'NON_NULL':
            // if NON_NULL appears before list, then the field/arg is non nullable
            // otherwise the INNER elements are non-nullable
            return getTypescriptField(fieldName, type.ofType, {
                isList: isList,
                isNullable: isList ? isNullable : false,
                isListItemNullable: isList ? false : isListItemNullable,
            });
        case 'LIST':
            return getTypescriptField(fieldName, type.ofType, {
                isList: true,
                isNullable: isNullable,
                isListItemNullable: isListItemNullable,
            });
        default:
            throw new Error("UNKNOWN_TYPE_KIND");
    }
}
exports.default = getTypescriptField;
var buildField = function (fieldName, typeName, isNullable, isList, isListItemNullable) {
    var nullableSymbol = isNullable ? '?' : '';
    if (isList) {
        // if list items can be nullable, allow for array to have undefined fields
        // NOTE: maybe this should be null and not undefined?
        var nullableItems = isListItemNullable
            ? "(" + typeName + " | undefined)"
            : typeName;
        return "" + fieldName + nullableSymbol + ": " + nullableItems + "[]";
    }
    else {
        return "" + fieldName + nullableSymbol + ": " + typeName;
    }
};
